@@ -1,4 +1,5 @@
 """Test pysma init."""
+import asyncio
 import logging
 import re
 from unittest.mock import patch
@@ -68,6 +69,18 @@ class Test_SMA_class:
         with pytest.raises(SmaConnectionException):
             await sma._get_json("/dummy-url")
 
+    async def test_timeout_error(self, mock_aioresponse):  # noqa: F811
+        """Test request_json with a SmaConnectionException from TimeoutError."""
+        mock_aioresponse.get(
+            f"{self.base_url}/dummy-url",
+            exception=asyncio.TimeoutError("mocked error"),
+            repeat=True,
+        )
+        session = aiohttp.ClientSession()
+        sma = SMA(session, self.host, "pass")
+        with pytest.raises(SmaConnectionException):
+            await sma._get_json("/dummy-url")
+
     @patch("pysma._LOGGER.warning")
     async def test_request_json_invalid_json(
         self, mock_warn, mock_aioresponse  # noqa: F811
